@@ -15,8 +15,8 @@ class Client:
     Methods
     -------
     get_ai_response(message: str, lang: str = 'en', type: str = 'stable'): Get random AI response.
-    get_image(type: str = 'any'): Get random image.
-    get_joke(type: str = 'any'): Get random joke.
+    get_image(type: str = 'any'): Get a random image.
+    get_joke(type: str = 'any'): Get a random joke.
     close(): Closes the session.
     """
     def __init__(self, key: str, version: str = "3"):
@@ -53,26 +53,30 @@ class Client:
                 return Joke(r_json)
             else:
                 raise HTTPError
+        elif r.status_code == 401:
+            raise AuthError(Exception)
         else:
             raise HTTPError
 
-    def get_ai_response(self, message: str, type: str = "stable", language: str = "en", unique_id: str = "", dev_name: str = "", bot_name: str = ""):
+    def get_ai_response(self, message: str, type: str = "stable", lang: str = "en", unique_id: str = "", dev_name: str = "", bot_name: str = ""):
         if type not in ["stable", "unstable"]:
             raise InvalidTypeError
 
         try:
             if self.version == "3":
-                r = self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={language}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}")
+                r = self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={lang}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}")
                 r_json = r.json()
                 if r.status_code == 200:
                     if r_json[0]["success"] is True:
                         return r_json[0]["message"]
                     else:
                         raise HTTPError
+                elif r.status_code == 401:
+                    raise AuthError(Exception)
                 else:
                     raise HTTPError
             else:
-                r = self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={language}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}&api_key={self.key}")
+                r = self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={lang}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}&api_key={self.key}")
                 r_json = r.json()
                 if len(r_json) == 1:
                     return r_json[0]
@@ -112,6 +116,8 @@ class Client:
 
         if r.status_code == 200:
             return Image(content, data[0])
+        elif r.status_code == 401:
+            raise AuthError(Exception)
         else:
             raise HTTPError
 
@@ -128,8 +134,8 @@ class AsyncClient:
     Methods
     -------
     async get_ai_response(message: str, lang: str = 'en', type: str = 'stable'): Get random AI response.
-    async get_image(type: str = 'any'): Get random image.
-    async get_joke(type: str = 'any'): Get random joke.
+    async get_image(type: str = 'any'): Get a random image.
+    async get_joke(type: str = 'any'): Get a random joke.
     async close(): Closes the session.
     """
     def __init__(self, key: str, version: str = "3"):
@@ -166,26 +172,30 @@ class AsyncClient:
                 return Joke(r_json)
             else:
                 raise HTTPError
+        elif r.status == 401:
+            raise AuthError(Exception)
         else:
             raise HTTPError
 
-    async def get_ai_response(self, message: str, type: str = "stable", language: str = "en", unique_id: str = "", dev_name: str = "", bot_name: str = ""):
+    async def get_ai_response(self, message: str, type: str = "stable", lang: str = "en", unique_id: str = "", dev_name: str = "", bot_name: str = ""):
         if type not in ["stable", "unstable"]:
             raise InvalidTypeError
 
         try:
             if self.version == "3":
-                r = await self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={language}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}")
+                r = await self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={lang}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}")
                 r_json = await r.json()
                 if r.status == 200:
                     if r_json[0]["success"] is True:
                         return r_json[0]["message"]
                     else:
                         raise HTTPError
+                elif r.status == 401:
+                    raise AuthError(Exception)
                 else:
                     raise HTTPError
             else:
-                r = await self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={language}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}&api_key={self.key}")
+                r = await self.session.get(f"{self.url}/ai/response?message={message}&type={type}&language={lang}&unique_id={unique_id}&dev_name={dev_name}&bot_name={bot_name}&api_key={self.key}")
                 r_json = await r.json()
                 if len(r_json) == 1:
                     return r_json[0]
@@ -225,6 +235,8 @@ class AsyncClient:
 
         if r.status == 200:
             return Image(content, data[0])
+        elif r.status == 401:
+            raise AuthError(Exception)
         else:
             raise HTTPError
 
